@@ -1,11 +1,10 @@
 ;;; ef-dark-theme.el --- Legible dark theme with blue, magenta, cyan, purple colors -*- lexical-binding:t -*-
 
-;; Copyright (C) 2022-2023  Free Software Foundation, Inc.
+;; Copyright (C) 2022-2024  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
-;; Maintainer: Ef-Themes Development <~protesilaos/ef-themes@lists.sr.ht>
-;; URL: https://git.sr.ht/~protesilaos/ef-themes
-;; Mailing-List: https://lists.sr.ht/~protesilaos/ef-themes
+;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
+;; URL: https://github.com/protesilaos/ef-themes
 ;; Keywords: faces, theme, accessibility
 
 ;; This file is NOT part of GNU Emacs.
@@ -87,18 +86,18 @@
 
 ;;; Basic hues for background values
 
-      (bg-red-intense     "#cd2f30")
-      (bg-green-intense   "#20a020")
+      (bg-red-intense     "#b02930")
+      (bg-green-intense   "#337133")
       (bg-yellow-intense  "#8f5040")
       (bg-blue-intense    "#4648d0")
-      (bg-magenta-intense "#a050cf")
-      (bg-cyan-intense    "#2270be")
+      (bg-magenta-intense "#804fdd")
+      (bg-cyan-intense    "#2270cf")
 
       (bg-red-subtle      "#72002a")
       (bg-green-subtle    "#00422a")
       (bg-yellow-subtle   "#603000")
       (bg-blue-subtle     "#242679")
-      (bg-magenta-subtle  "#5a105f")
+      (bg-magenta-subtle  "#501f72")
       (bg-cyan-subtle     "#004065")
 
 ;;; Diffs
@@ -166,6 +165,9 @@
 
 ;;;; General mappings
 
+      (bg-fringe unspecified)
+      (fg-fringe unspecified)
+
       (err red-warmer)
       (warning yellow)
       (info green)
@@ -238,6 +240,17 @@
       (mail-subject blue-cooler)
       (mail-other cyan)
 
+;;;; Search mappings
+
+      (bg-search-current bg-yellow-intense)
+      (bg-search-lazy bg-blue-intense)
+      (bg-search-replace bg-red-intense)
+
+      (bg-search-rx-group-0 bg-magenta-intense)
+      (bg-search-rx-group-1 bg-green-intense)
+      (bg-search-rx-group-2 bg-red-subtle)
+      (bg-search-rx-group-3 bg-cyan-subtle)
+
 ;;;; Space mappings
 
       (bg-space unspecified)
