@@ -1,11 +1,10 @@
 ;;; ef-elea-dark-theme.el --- Legible dark theme with brown, magenta, and green colors -*- lexical-binding:t -*-
 
-;; Copyright (C) 2022-2023  Free Software Foundation, Inc.
+;; Copyright (C) 2022-2024  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
-;; Maintainer: Ef-Themes Development <~protesilaos/ef-themes@lists.sr.ht>
-;; URL: https://git.sr.ht/~protesilaos/ef-themes
-;; Mailing-List: https://lists.sr.ht/~protesilaos/ef-themes
+;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
+;; URL: https://github.com/protesilaos/ef-themes
 ;; Keywords: faces, theme, accessibility
 
 ;; This file is NOT part of GNU Emacs.
@@ -88,7 +87,7 @@
 ;;; Basic hues for background values
 
       (bg-red-intense     "#bd1f30")
-      (bg-green-intense   "#20a420")
+      (bg-green-intense   "#408420")
       (bg-yellow-intense  "#847020")
       (bg-blue-intense    "#2f5f9f")
       (bg-magenta-intense "#b05fcf")
@@ -97,8 +96,8 @@
       (bg-red-subtle      "#6a102a")
       (bg-green-subtle    "#00522a")
       (bg-yellow-subtle   "#5a4000")
-      (bg-blue-subtle     "#243679")
-      (bg-magenta-subtle  "#50205a")
+      (bg-blue-subtle     "#243788")
+      (bg-magenta-subtle  "#422e6b")
       (bg-cyan-subtle     "#005065")
 
 ;;; Diffs
@@ -166,6 +165,9 @@
 
 ;;;; General mappings
 
+      (bg-fringe unspecified)
+      (fg-fringe unspecified)
+
       (err red-warmer)
       (warning yellow-warmer)
       (info green-cooler)
@@ -238,6 +240,17 @@
       (mail-subject green-cooler)
       (mail-other green)
 
+;;;; Search mappings
+
+      (bg-search-current bg-yellow-intense)
+      (bg-search-lazy bg-blue-intense)
+      (bg-search-replace bg-red-intense)
+
+      (bg-search-rx-group-0 bg-magenta-intense)
+      (bg-search-rx-group-1 bg-green-intense)
+      (bg-search-rx-group-2 bg-red-subtle)
+      (bg-search-rx-group-3 bg-cyan-subtle)
+
 ;;;; Space mappings
 
       (bg-space unspecified)
